@@ -15,7 +15,7 @@ class SessionHandler():
   def to_database(self, overwrite = False):
     session = self.create_session()
     obj = self
-    if overwrite == True: obj = self.update_or_create(session, obj)
+    if overwrite == True: obj = self.get_or_create(session, obj)
     session.add(obj)
     self.commit(session)
     return(self)
@@ -23,25 +23,17 @@ class SessionHandler():
   def all_to_database(self, obj_list, overwrite = False):
     session = self.create_session()
     for obj in obj_list:
-      if overwrite == True:
-        session = self.update_or_create(session, obj)
-      else:
-        session.add(obj)
+      if overwrite == True: obj = self.get_or_create(session, obj)
+      session.add(obj)
     return self.commit(session)
   
-  def update_or_create(self,session,obj):
-    session_tmp = self.create_session()
-    keys = [key.name for key in inspect(obj.__class__).primary_key]
-    key_values = {k: v for k, v in obj.__dict__.items() if v and k in keys}
-    params = {k: v for k, v in obj.__dict__.items() if k.startswith("_") == False and k not in keys}
-    q = session_tmp.query(obj.__class__).filter_by(**key_values)
-    if q.count()==1:
-      q.update(params)
-      self.commit(session_tmp)
+  def get_or_create(self,session, obj):
+    params = {k: v for k, v in obj.__dict__.items() if v and k.startswith("_") == False}
+    instance = session.query(obj.__class__).filter_by(**params).first()
+    if instance:
+        return instance
     else:
-      session.add(obj)
-    return session
-      
+      obj
   
   def get_all(self, classname):
     session = self.create_session()   
